/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CECILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.web;

import static fr.unistra.sil.erp.back.WebMvcConfig.WEB_MAPPING_REGISTRY;

import fr.unistra.sil.erp.back.model.RegistryInfo;
import fr.unistra.sil.erp.back.repository.DatabaseConnectionException;
import fr.unistra.sil.erp.back.model.RegistryEntry;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import fr.unistra.sil.erp.back.repository.IRegistryRepository;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PostMapping;

/**
 * Web controller for the registry display page.
 *
 * @author antoine.beauvais
 */
@Controller
public class WebRegistryController {

    private final IRegistryRepository repository;

    /**
     * @param repository registry repository
     */
    public WebRegistryController(IRegistryRepository repository) {
        this.repository = repository;
    }

    /**
     * Returns the registry view for the Web interface.
     *
     * @param model the model to populate the template with.
     * @return the view.
     */
    @GetMapping(WEB_MAPPING_REGISTRY)
    public String registry(Model model) {
        try {
            List<RegistryEntry> lr = repository.getRegistry();
            model.addAttribute("registry", lr);
        } catch (DatabaseConnectionException ex) {
            Logger.getLogger(WebRegistryController.class.getName()).log(Level.SEVERE, null, ex);
        }
        return "registry";
    }

    @PostMapping(WEB_MAPPING_REGISTRY)
    public ResponseEntity<Object> createUser(@ModelAttribute RegistryInfo registryInfo) throws ParseException {
        RegistryEntry entry = new RegistryEntry(
                0,
                registryInfo.getTransactionType(),
                (new SimpleDateFormat()).parse(registryInfo.getDate()),
                registryInfo.getAccountId(),
                registryInfo.getDebit(),
                registryInfo.getCredit(),
                registryInfo.getRemarks()
        );
        entry = repository.store(entry);
        return new ResponseEntity<>(entry, HttpStatus.CREATED);
    }
}
