/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.model;

import com.fasterxml.jackson.annotation.JsonProperty;

import java.math.BigDecimal;

/**
 * Item object.
 * 
 * Items are products that can be bought and sold.
 * 
 * Any transaction must be linked to an item.
 * 
 * Items have specific quantities stored as "stocks" and cannot be sold
 * if the quantity is depleted.
 * 
 * @author BEAUVAIS ANTOINE
 */
public class Item {

    /**
     * The product's reference number.
     */
    private final Integer id;

    /**
     * The product's name.
     */
    private final String name;

    /**
     * The product's regular price.
     */
    private final BigDecimal price;

    /**
     * The product's price for subscribers.
     */
    @JsonProperty("subscriber_price")
    private final BigDecimal subscriberPrice;

    private final Category category;

    /**
     * Class constructor.
     *
     * @param id              Item ID.
     * @param name            Item name.
     * @param price           Item price.
     * @param subscriberPrice The item's price.
     * @param category        Item category.
     */
    public Item(Integer id, String name, BigDecimal price,
                BigDecimal subscriberPrice, Category category) {
        this.id = id;
        this.name = name;
        this.price = price;
        this.subscriberPrice = subscriberPrice;
        this.category = category;
    }

    /**
     * Returns the current item's reference number.
     *
     * @return the reference number.
     */
    public Integer getId() {
        return this.id;
    }

    /**
     * Returns the current item's name.
     *
     * @return the name.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Returns the current item's price.
     *
     * @return the price.
     */
    public BigDecimal getPrice() {
        return this.price;
    }

    /**
     * Returns the current item's price for subscribers.
     *
     * @return the price for subscribers.
     */
    public BigDecimal getSubscriberPrice() {
        return this.subscriberPrice;
    }

    /**
     * Returns the current item's category identifier.
     *
     * @return the category identifier.
     */
    public Category getCategory() {
        return this.category;
    }

}